test
Author: unknown

DitIDtest.p.1.s.1.w.1
Text Dit
PoSVNW(aanw,pron,stan,vol,3o,ev)
Lemmadit
Morphologydit
ChunkNP Dit
Dependencysu Head: is Dep: Dit
isIDtest.p.1.s.1.w.2
Text is
PoSWW(pv,tgw,ev)
Lemmazijn
Morphologyzijn
ChunkVP is
Dependencysu Head: is Dep: Dit
Dependencypredc Head: is Dep: zin
deIDtest.p.1.s.1.w.3
Text de
PoSLID(bep,stan,rest)
Lemmade
Morphologyde
ChunkNP de eerste zin
Dependencydet Head: zin Dep: de
eersteIDtest.p.1.s.1.w.4
Text eerste
PoSTW(rang,prenom,stan)
Lemmaeen
Lemmaeerste
Lemmaéén
Morphologyeen ste
ChunkNP de eerste zin
Dependencymod Head: zin Dep: eerste
zinIDtest.p.1.s.1.w.5
Text zin
PoSN(soort,ev,basis,zijd,stan)
Lemmazin
Morphologyzin
ChunkNP de eerste zin
Dependencydet Head: zin Dep: de
Dependencymod Head: zin Dep: eerste
Dependencypredc Head: is Dep: zin
Dependencymod Head: zin Dep: van
vanIDtest.p.1.s.1.w.6
Text van
PoSVZ(init)
Lemmavan
Morphologyvan
ChunkPP van
Dependencymod Head: zin Dep: van
Dependencyobj1 Head: van Dep: paragraaf
deIDtest.p.1.s.1.w.7
Text de
PoSLID(bep,stan,rest)
Lemmade
Morphologyde
ChunkNP de paragraaf
Dependencydet Head: paragraaf Dep: de
paragraafIDtest.p.1.s.1.w.8
Text paragraaf
PoSN(soort,ev,basis,zijd,stan)
Lemmaparagraaf
Morphologyparagraaf
ChunkNP de paragraaf
Dependencydet Head: paragraaf Dep: de
Dependencyobj1 Head: van Dep: paragraaf
Dependencypunct Head: paragraaf Dep: .
.IDtest.p.1.s.1.w.9
Text .
PoSLET()
Lemma.
Morphology.
Dependencypunct Head: paragraaf Dep: .
DitIDtest.p.1.s.2.w.1
Text Dit
PoSVNW(aanw,pron,stan,vol,3o,ev)
Lemmadit
Morphologydit
ChunkNP Dit
Dependencysu Head: is Dep: Dit
isIDtest.p.1.s.2.w.2
Text is
PoSWW(pv,tgw,ev)
Lemmazijn
Morphologyzijn
ChunkVP is
Dependencysu Head: is Dep: Dit
Dependencypredc Head: is Dep: zin
deIDtest.p.1.s.2.w.3
Text de
PoSLID(bep,stan,rest)
Lemmade
Morphologyde
ChunkNP de tweede zin
Dependencydet Head: zin Dep: de
tweedeIDtest.p.1.s.2.w.4
Text tweede
PoSTW(rang,prenom,stan)
Lemmatwee
Lemmatweede
Morphologytwee de
ChunkNP de tweede zin
Dependencymod Head: zin Dep: tweede
zinIDtest.p.1.s.2.w.5
Text zin
PoSN(soort,ev,basis,zijd,stan)
Lemmazin
Morphologyzin
ChunkNP de tweede zin
Dependencydet Head: zin Dep: de
Dependencymod Head: zin Dep: tweede
Dependencypredc Head: is Dep: zin
Dependencymod Head: zin Dep: van
vanIDtest.p.1.s.2.w.6
Text van
PoSVZ(init)
Lemmavan
Morphologyvan
ChunkPP van
Dependencymod Head: zin Dep: van
Dependencyobj1 Head: van Dep: paragraaf
deIDtest.p.1.s.2.w.7
Text de
PoSLID(bep,stan,rest)
Lemmade
Morphologyde
ChunkNP de paragraaf
Dependencydet Head: paragraaf Dep: de
paragraafIDtest.p.1.s.2.w.8
Text paragraaf
PoSN(soort,ev,basis,zijd,stan)
Lemmaparagraaf
Morphologyparagraaf
ChunkNP de paragraaf
Dependencydet Head: paragraaf Dep: de
Dependencyobj1 Head: van Dep: paragraaf
Dependencypunct Head: paragraaf Dep: .
.IDtest.p.1.s.2.w.9
Text .
PoSLET()
Lemma.
Morphology.
Dependencypunct Head: paragraaf Dep: .
EnIDtest.p.1.s.3.w.1
Text En
PoSVG(neven)
Lemmaen
Morphologyen
ChunkPP En
Dependencycnj Head: En Dep: laatste
ditIDtest.p.1.s.3.w.2
Text dit
PoSVNW(aanw,pron,stan,vol,3o,ev)
Lemmadit
Morphologydit
ChunkNP dit
DependencyNone Head: laatste Dep: dit
deIDtest.p.1.s.3.w.3
Text de
PoSLID(bep,stan,rest)
Lemmade
Morphologyde
ChunkNP de laatste
Dependencydet Head: laatste Dep: de
laatsteIDtest.p.1.s.3.w.4
Text laatste
PoSADJ(nom,sup,met-e,zonder-n,stan)
Lemmalaat
Morphologylaat st e
Morphologylaatst e
ChunkNP de laatste
DependencyNone Head: laatste Dep: dit
Dependencydet Head: laatste Dep: de
Dependencycnj Head: En Dep: laatste
Dependencypunct Head: laatste Dep: .
.IDtest.p.1.s.3.w.5
Text .
PoSLET()
Lemma.
Morphology.
Dependencypunct Head: laatste Dep: .

DitIDtest.p.2.s.1.w.1
Text Dit
PoSVNW(aanw,pron,stan,vol,3o,ev)
Lemmadit
Morphologydit
ChunkNP Dit
Dependencysu Head: is Dep: Dit
isIDtest.p.2.s.1.w.2
Text is
PoSWW(pv,tgw,ev)
Lemmazijn
Morphologyzijn
ChunkVP is
Dependencysu Head: is Dep: Dit
Dependencypredc Head: is Dep: zin
éénIDtest.p.2.s.1.w.3
Text één
PoSTW(hoofd,prenom,stan)
Lemmaeen
Lemmaéén
Morphologyéén
ChunkNP één zin
Dependencydet Head: zin Dep: één
zinIDtest.p.2.s.1.w.4
Text zin
PoSN(soort,ev,basis,zijd,stan)
Lemmazin
Morphologyzin
ChunkNP één zin
Dependencydet Head: zin Dep: één
Dependencypredc Head: is Dep: zin
Dependencymod Head: zin Dep: in
inIDtest.p.2.s.1.w.5
Text in
PoSVZ(init)
Lemmain
Morphologyin
ChunkPP in
Dependencymod Head: zin Dep: in
Dependencyobj1 Head: in Dep: paragraaf
eenIDtest.p.2.s.1.w.6
Text een
PoSLID(onbep,stan,agr)
Lemmaeen
Morphologyeen
ChunkNP een nieuwe paragraaf
Dependencydet Head: paragraaf Dep: een
nieuweIDtest.p.2.s.1.w.7
Text nieuwe
PoSADJ(prenom,basis,met-e,stan)
Lemmanieuw
Morphologynieuw e
ChunkNP een nieuwe paragraaf
Dependencymod Head: paragraaf Dep: nieuwe
paragraafIDtest.p.2.s.1.w.8
Text paragraaf
PoSN(soort,ev,basis,zijd,stan)
Lemmaparagraaf
Morphologyparagraaf
ChunkNP een nieuwe paragraaf
Dependencydet Head: paragraaf Dep: een
Dependencymod Head: paragraaf Dep: nieuwe
Dependencyobj1 Head: in Dep: paragraaf
Dependencypunct Head: paragraaf Dep: .
.IDtest.p.2.s.1.w.9
Text .
PoSLET()
Lemma.
Morphology.
Dependencypunct Head: paragraaf Dep: .

DitIDtest.p.3.s.1.w.1
Text Dit
PoSVNW(aanw,pron,stan,vol,3o,ev)
Lemmadit
Morphologydit
ChunkNP Dit
Dependencysu Head: is Dep: Dit
isIDtest.p.3.s.1.w.2
Text is
PoSWW(pv,tgw,ev)
Lemmazijn
Morphologyzijn
ChunkVP is
Dependencysu Head: is Dep: Dit
Dependencymod Head: is Dep: ook
Dependencypredc Head: is Dep: zin
ookIDtest.p.3.s.1.w.3
Text ook
PoSBW()
Lemmaook
Morphologyook
ChunkADVP ook
Dependencymod Head: is Dep: ook
eenIDtest.p.3.s.1.w.4
Text een
PoSLID(onbep,stan,agr)
Lemmaeen
Morphologyeen
ChunkNP een zin
Dependencydet Head: zin Dep: een
zinIDtest.p.3.s.1.w.5
Text zin
PoSN(soort,ev,basis,zijd,stan)
Lemmazin
Morphologyzin
ChunkNP een zin
Dependencydet Head: zin Dep: een
Dependencypredc Head: is Dep: zin
Dependencypunct Head: zin Dep: .
.IDtest.p.3.s.1.w.6
Text .
PoSLET()
Lemma.
Morphology.
Dependencypunct Head: zin Dep: .
DezeIDtest.p.3.s.2.w.1
Text Deze
PoSVNW(aanw,det,stan,prenom,met-e,rest)
Lemmadeze
Morphologydeze
ChunkNP Deze
staatIDtest.p.3.s.2.w.2
Text staat
PoSWW(pv,tgw,met-t)
Lemmastaan
Morphologysta t
ChunkVP staat
Dependencyld Head: staat Dep: in
inIDtest.p.3.s.2.w.3
Text in
PoSVZ(init)
Lemmain
Morphologyin
ChunkPP in
Dependencyld Head: staat Dep: in
Dependencyobj1 Head: in Dep: paragraaf
deIDtest.p.3.s.2.w.4
Text de
PoSLID(bep,stan,rest)
Lemmade
Morphologyde
ChunkNP de derde paragraaf
Dependencydet Head: paragraaf Dep: de
derdeIDtest.p.3.s.2.w.5
Text derde
PoSTW(rang,prenom,stan)
Lemmadrie
Morphologyderde
ChunkNP de derde paragraaf
Dependencymod Head: paragraaf Dep: derde
paragraafIDtest.p.3.s.2.w.6
Text paragraaf
PoSN(soort,ev,basis,zijd,stan)
Lemmaparagraaf
Morphologyparagraaf
ChunkNP de derde paragraaf
Dependencydet Head: paragraaf Dep: de
Dependencymod Head: paragraaf Dep: derde
Dependencyobj1 Head: in Dep: paragraaf
Dependencypunct Head: paragraaf Dep: .
.IDtest.p.3.s.2.w.7
Text .
PoSLET()
Lemma.
Morphology.
Dependencypunct Head: paragraaf Dep: .